@@ -4,10 +4,12 @@ use strict;
 use URI;
 use Net::LDAP;
 use Net::LDAP::Constant qw(:all);
+use POSIX;
 use Encode;
-use Sys::Syslog;
-use Sys::Syslog qw(:macros);
 use Data::Dumper;
+if ($^O ne 'MSWin32') {
+    eval "use Sys::Syslog";
+}
 
 =head1 NAME
 
@@ -65,16 +67,6 @@ sub init
     my $self = shift;
     my $conf = $self->{_config};
 
-    $conf->{numloglevel} = {debug => LOG_DEBUG,
-                            info => LOG_INFO,
-                            notice => LOG_NOTICE,
-                            warning => LOG_WARNING,
-                            error => LOG_ERR,
-                            critical => LOG_CRIT,
-                            alert => LOG_ALERT,
-                            emergency => LOG_EMERG
-                           };
-
     # check configuration
     if ($self->_checkConfig()) {
         $self->log(level => 'alert', message => "Configuration error");
@@ -309,10 +301,14 @@ sub log
         $p{'message'} = encode('utf8', $p{'message'});
     }
 
-    openlog('LISM', 'pid', 'local4');
-    setlogmask(Sys::Syslog::LOG_UPTO($conf->{numloglevel}{$conf->{sysloglevel}}));
-    syslog($conf->{numloglevel}{$p{'level'}}, $p{'message'});
-    closelog
+    if ($^O ne 'MSWin32') {
+        openlog('LISM', 'pid', 'local4');
+        setlogmask(Sys::Syslog::LOG_UPTO(Sys::Syslog::xlate($conf->{sysloglevel})));
+        syslog($p{'level'}, $p{'message'});
+        closelog();
+    } else {
+        print STDERR strftime("%Y %m %d %H:%M:%S", localtime(time))." $p{'message'}\n";
+    }
 }
 
 sub _checkConfig
@@ -349,7 +345,7 @@ sub _searchLdap
     if (defined($ldapopts->{ldap})) {
         my $cmsg = $ldapopts->{ldap}->bind($ldapopts->{binddn}, password => $ldapopts->{bindpw});
         if ($cmsg->code) {
-            $self->log(level => 'error', message => "LDAP connection check failed in handler");
+            $self->log(level => 'err', message => "LDAP connection check failed in handler");
             $ldapopts->{ldap}->unbind();
             undef($ldapopts->{ldap});
         }
@@ -358,14 +354,14 @@ sub _searchLdap
     if (!$ldapopts->{ldap}) {
         $ldapopts->{ldap} = Net::LDAP->new($ldapopts->{uri});
         if (!defined($ldapopts->{ldap})) {
-            $self->log(level => 'error', message => "Can't connect $ldapopts->{uri}");
+            $self->log(level => 'err', message => "Can't connect $ldapopts->{uri}");
             return undef;
         }
 
         $msg = $ldapopts->{ldap}->bind($ldapopts->{binddn}, password => $ldapopts->{bindpw});
         $rc = $msg->code;
         if ($rc) {
-            $self->log(level => 'error', message => "bind by $ldapopts->{binddn}failed($rc)");
+            $self->log(level => 'err', message => "bind by $ldapopts->{binddn}failed($rc)");
             return undef;
         }
     }
@@ -380,7 +376,7 @@ sub _searchLdap
 
     $rc = $msg->code;
     if ($rc) {
-        $self->log(level => 'error', message => "search by $filter failed($rc)");
+        $self->log(level => 'err', message => "search by $filter failed($rc)");
         if ($rc == LDAP_SERVER_DOWN) {
             $ldapopts->{ldap}->unbind();
             undef($ldapopts->{ldap});
