@@ -3,8 +3,6 @@ package LISM::Handler::Rewrite;
 use strict;
 use base qw(LISM::Handler);
 use Encode;
-use Sys::Syslog;
-use Sys::Syslog qw(:macros);
 use Data::Dumper;
 
 =head1 NAME
@@ -42,7 +40,7 @@ sub pre_bind
 
             my $str = $self->_rewriteParse($rule->{match}, $substitution, ${$binddnp});
             if (!$str) {
-                $self->log(level => 'error', message => "bind rewrite \"${$binddnp}\" failed");
+                $self->log(level => 'err', message => "bind rewrite \"${$binddnp}\" failed");
                 return -1;
             }
             ${$binddnp} = $str;
@@ -76,14 +74,14 @@ sub pre_compare
 
             my $str = $self->_rewriteParse($rule->{match}, $substitution, ${$dnp}, \%rwcache);
             if (!$str) {
-                $self->log(level => 'error', message => "compare rewrite \"${$dnp}\" failed");
+                $self->log(level => 'err', message => "compare rewrite \"${$dnp}\" failed");
                 return -1;
             }
             ${$dnp} = $str;
 
             $str = $self->_rewriteParse($rule->{match}, $substitution, ${$avaStrp}, \%rwcache);
             if (!$str) {
-                $self->log(level => 'error', message => "compcare rewrite \"${$dnp}\" failed");
+                $self->log(level => 'err', message => "compcare rewrite \"${$dnp}\" failed");
                 return -1;
              }
              ${$avaStrp} = $str;
@@ -117,14 +115,14 @@ sub pre_search
             $substitution =~ s/%0/${$basep}\n${$filterStrp}/;
             my $str = $self->_rewriteParse($rule->{match}, $substitution, ${$basep}, \%rwcache);
             if (!defined($str)) {
-                $self->log(level => 'error', message => "search rewrite \"${$basep}\" failed");
+                $self->log(level => 'err', message => "search rewrite \"${$basep}\" failed");
                 return -1;
             }
             ${$basep} = $str;
 
             $str = $self->_rewriteParse($rule->{match}, $substitution, ${$filterStrp}, \%rwcache);
             if (!defined($str)) {
-                $self->log(level => 'error', message => "search rewrite \"${$filterStrp}\" failed");
+                $self->log(level => 'err', message => "search rewrite \"${$filterStrp}\" failed");
                 return -1;
             }
             ${$filterStrp} = $str;
@@ -164,7 +162,7 @@ sub post_search
 
                 my $str = $self->_rewriteParse($rule->{match}, $substitution, $dn, \%rwcache);
                 if (!$str) {
-                    $self->log(level => 'error', message => "search result rewrite \"$dn\" failed");
+                    $self->log(level => 'err', message => "search result rewrite \"$dn\" failed");
                     next;
                 }
                 $line[0] = "dn: $str";
@@ -173,7 +171,7 @@ sub post_search
                 for (my $j = 1; $j < @line; $j++) {
                     $line[$j] = $self->_rewriteParse($rule->{match}, $substitution, $line[$j], \%rwcache);
                     if (!defined($line[$j])) {
-                        $self->log(level => 'error', message => "search result rewrite \"$dn\" failed");
+                        $self->log(level => 'err', message => "search result rewrite \"$dn\" failed");
                         $rc = -1;
                         last;
                     } elsif ($line[$j]) {
@@ -217,7 +215,7 @@ sub pre_modify
 
             my $str = $self->_rewriteParse($rule->{match}, $substitution, ${$dnp}, \%rwcache);
             if (!$str) {
-                $self->log(level => 'error', message => "modify rewrite \"${$dnp}\" failed");
+                $self->log(level => 'err', message => "modify rewrite \"${$dnp}\" failed");
                 return -1;
             }
             ${$dnp} = $str;
@@ -239,7 +237,7 @@ sub pre_modify
                     for (my $i =0; $i < @values; $i++) {
                         $str = $self->_rewriteParse($rule->{match}, $substitution, "$attr: ".$values[$i], \%rwcache);
                         if (!defined($str)) {
-                            $self->log(level => 'error', message => "modify rewrite \"${$dnp}\" failed");
+                            $self->log(level => 'err', message => "modify rewrite \"${$dnp}\" failed");
                             return -1;
                         } elsif ($str) {
                             foreach my $line (split(/\n/, $str)) {
@@ -291,7 +289,7 @@ sub pre_add
 
             my $str = $self->_rewriteParse($rule->{match}, $substitution, ${$dnp}, \%rwcache);
             if (!$str) {
-                $self->log(level => 'error', message => "add rewrite \"${$dnp}\" failed");
+                $self->log(level => 'err', message => "add rewrite \"${$dnp}\" failed");
                 return -1;
             }
             ${$dnp} = $str;
@@ -301,7 +299,7 @@ sub pre_add
             for (my $i = 0; $i < @line; $i++) {
                 $line[$i] = $self->_rewriteParse($rule->{match}, $substitution, $line[$i], \%rwcache);
                 if (!defined($line[$i])) {
-                    $self->log(level => 'error', message => "add rewrite \"${$dnp}\" failed");
+                    $self->log(level => 'err', message => "add rewrite \"${$dnp}\" failed");
                     return -1;
                 }
             }
@@ -336,14 +334,14 @@ sub pre_modrdn
 
             my $str = $self->_rewriteParse($rule->{match}, $substitution, ${$dnp}, \%rwcache);
             if (!$str) {
-                $self->log(level => 'error', message => "modrdn rewrite \"${$dnp}\" failed");
+                $self->log(level => 'err', message => "modrdn rewrite \"${$dnp}\" failed");
                 return -1;
             }
             ${$dnp} = $str;
 
             $str = $self->_rewriteParse($rule->{match}, $substitution, ${$argsp}[0], \%rwcache);
             if (!$str) {
-                $self->log(level => 'error', message => "modrdn rewrite \"${$dnp}\" failed");
+                $self->log(level => 'err', message => "modrdn rewrite \"${$dnp}\" failed");
                 return -1;
             }
             ${$argsp}[0] = $str;
@@ -378,7 +376,7 @@ sub pre_delete
 
             my $str = $self->_rewriteParse($rule->{match}, $substitution, ${$dnp});
             if (!$str) {
-                $self->log(level => 'error', message => "delete rewrite \"${$dnp}\" failed");
+                $self->log(level => 'err', message => "delete rewrite \"${$dnp}\" failed");
                 return -1;
             }
             ${$dnp} = $str;
@@ -471,7 +469,7 @@ sub _rewriteParse
                 return $str;
             }
 
-            $rwmap =~ s/([()])/\\$1/g;
+            $rwmap =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
             my @tmpsubs;
             foreach my $sub (@subs) {
                 foreach my $value (@values) {
@@ -528,7 +526,7 @@ sub _functionMap
 
     eval "\@values = $map_name($map_args)";
     if ($@) {
-        $self->log(level => 'error', message => "rewriteMap $map_name failed: $@");
+        $self->log(level => 'err', message => "rewriteMap $map_name failed: $@");
         return undef;
     }
 
