@@ -7,9 +7,10 @@ use Digest::SHA1;
 use MIME::Base64;
 use POSIX;
 use Encode;
-use Sys::Syslog;
-use Sys::Syslog qw(:macros);
 use Data::Dumper;
+if ($^O ne 'MSWin32') {
+    eval "use Sys::Syslog";
+}
 
 our $maxLoopCount = 10;
 
@@ -73,16 +74,6 @@ sub init
     my $self = shift;
     my $conf = $self->{_config};
 
-    $conf->{numloglevel} = {debug => LOG_DEBUG,
-                            info => LOG_INFO,
-                            notice => LOG_NOTICE,
-                            warning => LOG_WARNING,
-                            error => LOG_ERR,
-                            critical => LOG_CRIT,
-                            alert => LOG_ALERT,
-                            emergency => LOG_EMERG
-                           };
-
     # check configuration
     if ($self->_checkConfig()) {
         $self->log(level => 'alert', message => "Configuration error");
@@ -511,10 +502,14 @@ sub log
         $p{'message'} = encode('utf8', $p{'message'});
     }
 
-    openlog('LISM', 'pid', 'local4');
-    setlogmask(Sys::Syslog::LOG_UPTO($conf->{numloglevel}{$conf->{sysloglevel}}));
-    syslog($conf->{numloglevel}{$p{'level'}}, $p{'message'});
-    closelog
+    if ($^O ne 'MSWin32') {
+        openlog('LISM', 'pid', 'local4');
+        setlogmask(Sys::Syslog::LOG_UPTO(Sys::Syslog::xlate($conf->{sysloglevel})));
+        syslog($p{'level'}, $p{'message'});
+        closelog();
+    } else {
+        print STDERR strftime("%Y %m %d %H:%M:%S", localtime(time))." $p{'message'}\n";
+    }
 }
 
 =pod
@@ -581,6 +576,24 @@ sub hashPasswd
 
 =pod
 
+=head2 hashType();
+
+get hash type.
+
+=cut
+
+sub hashType
+{
+    my $self = shift;
+    my $conf = $self->{_config};
+
+    my ($htype, $otype) = split(/:/, $conf->{hash});
+
+    return $htype;
+}
+
+=pod
+
 =head2 parseFilter($filter, $entry)
 
 parse filter and check entry matching.
@@ -630,7 +643,13 @@ sub parseFilter
         }
         return $rc;
     } elsif ($op eq 'substrings') {
-        return $entry =~ /^$args->{type}: $args->{substrings}[0]{initial}*$args->{substrings}[1]{final}$/mi;
+        if (defined($args->{substrings}[0]{initial})) {
+            return $entry =~ /^$args->{type}: $args->{substrings}[0]{initial}.*$/mi;
+        } elsif (defined($args->{substrings}[0]{final})) {
+            return $entry =~ /^$args->{type}: .*$args->{substrings}[0]{final}$/mi;
+        } else {
+            return $entry =~ /^$args->{type}: .*$args->{substrings}[0]{any}.*$/mi;
+        }
     } elsif ($op eq 'present') {
         return $entry =~ /^$args: /mi;
     }
@@ -686,6 +705,11 @@ sub _checkConfig
         }
     }
 
+    # hash type
+    if (!defined($conf->{hash})) {
+        $conf->{hash} = 'PLAINTEXT';
+    }
+
     # multibyte character code
     if (defined($conf->{mbcode})) {
         if ($conf->{mbcode}[0] !~ /^(utf8|euc-jp|shiftjis|cp932)/) {
@@ -1137,7 +1161,7 @@ sub _funcParse
 
         eval "\$value = $func";
         if ($@) {
-            $self->log(level => 'error', message => "function $func failed: $@");
+            $self->log(level => 'err', message => "function $func failed: $@");
         }
 
         $func =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
@@ -1159,8 +1183,7 @@ sub _pwdFormat
 
         if ($htype =~ /^CRYPT|MD5|SHA$/i) {
             if ($otype =~ /^hex$/i && $htype =~ /^MD5|SHA$/i) {
-                $passwd = encode_base64(pack("H*", $passwd));
-                chop $passwd;
+                $passwd = encode_base64(pack("H*", $passwd), '');
             }
             $passwd = "{$htype}".$passwd;
         }
