@@ -5,8 +5,6 @@ use base qw(LISM::Storage);
 use Net::LDAP::Constant qw(:all);
 use Net::LDAP::Filter;
 use Encode;
-use Sys::Syslog;
-use Sys::Syslog qw(:macros);
 use Data::Dumper;
 
 =head1 NAME
@@ -159,7 +157,7 @@ sub _objSearch
         }
 
         while (<$file>) {
-            chop;
+            s/\r|\n|\r\n$//;
             my @data = split(/$dlm/);
             my $entry;
 
@@ -323,7 +321,7 @@ sub _objModify
                 }
 
                 if (grep(/\r/, @values)) {
-                    $self->log(level => 'error', message => "CSV field can't contain carriage return");
+                    $self->log(level => 'err', message => "CSV field can't contain carriage return");
                     $rc = LDAP_UNWILLING_TO_PERFORM;
                     last;
                 }
@@ -344,7 +342,7 @@ sub _objModify
                     # convert the value to object's id
                     ($rc, @keys) = $self->_getAttrKeys($oconf, $attr, @values);
                     if ($rc) {
-                        $self->log(level => 'error', message => "Can't get id of $attr values in the file");
+                        $self->log(level => 'err', message => "Can't get id of $attr values in the file");
                         $rc = LDAP_OTHER;
                         last DO;
                     }
@@ -498,7 +496,7 @@ sub _objAdd
                 my $coln;
                 my @values = ($entryStr =~ /^$attr:\s(.*)$/gmi);
                 if (grep(/\r/, @values)) {
-                    $self->log(level => 'error', message => "CSV field can't contain carriage return");
+                    $self->log(level => 'err', message => "CSV field can't contain carriage return");
                     $rc = LDAP_UNWILLING_TO_PERFORM;
                     last DO;
                 }
@@ -512,7 +510,7 @@ sub _objAdd
                     # convert the value to object's id
                     ($rc, @keys) = $self->_getAttrKeys($oconf, $attr, @values);
                     if ($rc) {
-                        $self->log(level => 'error', message => "Can't get id of $attr values in the file");
+                        $self->log(level => 'err', message => "Can't get id of $attr values in the file");
                         $rc = LDAP_OTHER;
                         last DO;
                     }
