@@ -6,8 +6,6 @@ use Net::LDAP;
 use Net::LDAP::Constant qw(:all);
 use MIME::Base64;
 use Encode;
-use Sys::Syslog;
-use Sys::Syslog qw(:macros);
 use Data::Dumper;
 
 our $rawattrs = '^(jpegphoto|photo|objectSid|objectGUID|.*;binary)$';
@@ -385,7 +383,7 @@ sub _getConnect
     if (defined($self->{ldap}) && defined($self->{bind})) {
         my $msg = $self->{ldap}->bind($conf->{binddn}[0], password => $conf->{bindpw}[0]);
         if ($msg->code) {
-            $self->log(level => 'error', message => "Connection check failed");
+            $self->log(level => 'err', message => "Connection check failed");
             $self->{ldap}->unbind();
             $self->{bind}->unbind();
             undef($self->{ldap});
