@@ -7,8 +7,6 @@ use Net::LDAP::Constant qw(:all);
 use DBI;
 use MIME::Base64;
 use Encode;
-use Sys::Syslog;
-use Sys::Syslog qw(:macros);
 use Data::Dumper;
 
 our $rawattrs = '^(jpegphoto|photo|.*;binary)$';
@@ -117,7 +115,7 @@ sub hashPasswd
 
         my $sth = $self->{db}->prepare("select password(\'$passwd\');");
         if (!$sth->execute) {
-            $self->log(level => 'error', message => "MySQL PASSWORD(\'$passwd\') failed: ".$sth->errstr);
+            $self->log(level => 'err', message => "MySQL PASSWORD(\'$passwd\') failed: ".$sth->errstr);
             return $passwd;
         }
         my @data = $sth->fetchrow_array;
@@ -136,7 +134,7 @@ sub _getConnect
     if (defined($self->{db})) {
         my $sth = $self->{db}->prepare("select 'check';");
         if (!$sth->execute) {
-            $self->log(level => 'error', message => "Connection check failed");
+            $self->log(level => 'err', message => "Connection check failed");
         } else {
             return 0;
         }
@@ -277,7 +275,7 @@ sub _objSearch
 
         my $sth = $self->{db}->prepare($sql);
         if (!$sth->execute) {
-            $self->log(level => 'error', message => "Searching by \"$sql\" failed: ".$sth->errstr);
+            $self->log(level => 'err', message => "Searching by \"$sql\" failed: ".$sth->errstr);
             $rc = LDAP_OPERATIONS_ERROR;
             @match_entries = ();
             last DO;
@@ -379,7 +377,7 @@ sub _objModify
     DO: {
         # start transaction
         if (!$self->{db}->begin_work) {
-            $self->log(level => 'error', message => "Can't begin: ".$self->{db}->errstr);
+            $self->log(level => 'err', message => "Can't begin: ".$self->{db}->errstr);
             $rc = LDAP_OPERATIONS_ERROR;
             last DO;
         }
@@ -460,7 +458,7 @@ sub _objModify
 
                     $sth = $self->{db}->prepare($sql);
                     if (!$sth->execute) {
-                        $self->log(level => 'error', message => "Adding values by \"$sql\" failed: ".$sth->errstr);
+                        $self->log(level => 'err', message => "Adding values by \"$sql\" failed: ".$sth->errstr);
                         $rc = LDAP_OPERATIONS_ERROR;
                         last DO;
                     }
@@ -494,7 +492,7 @@ sub _objModify
 
                     $sth = $self->{db}->prepare($sql);
                     if (!$sth->execute) {
-                        $self->log(level => 'error', message => "Deleting values by \"$sql\" failed: ".$sth->errstr);
+                        $self->log(level => 'err', message => "Deleting values by \"$sql\" failed: ".$sth->errstr);
                         $rc = LDAP_OPERATIONS_ERROR;
                         last DO;
                     }
@@ -532,7 +530,7 @@ sub _objModify
 
                     $sth = $self->{db}->prepare($sql);
                     if (!$sth->execute) {
-                        $self->log(level => 'error', message => "Replacing values by \"$sql\" failed: ".$sth->errstr);
+                        $self->log(level => 'err', message => "Replacing values by \"$sql\" failed: ".$sth->errstr);
                         $rc = LDAP_OPERATIONS_ERROR;
                         last DO;
                     }
@@ -613,7 +611,7 @@ sub _objAdd
     DO: {
         # start transaction
         if (!$self->{db}->begin_work) {
-            $self->log(level => 'error', message => "Can't begin: ".$self->{db}->errstr);
+            $self->log(level => 'err', message => "Can't begin: ".$self->{db}->errstr);
             $rc = LDAP_OPERATIONS_ERROR;
             last DO;
         }
@@ -685,7 +683,7 @@ sub _objAdd
 
         my $sth = $self->{db}->prepare("$sql");
         if (!$sth->execute) {
-            $self->log(level => 'error', message => "Adding entry by \"$sql\" failed: ".$sth->errstr);
+            $self->log(level => 'err', message => "Adding entry by \"$sql\" failed: ".$sth->errstr);
             $rc = LDAP_OPERATIONS_ERROR;
             last DO;
         }
@@ -698,7 +696,7 @@ sub _objAdd
 
         ($rc, $keys) = $self->_objSearch($obj, '', $pdn, -1, $filter);
         if ($rc || !@{$keys}) {
-            $self->log(level => 'error', message => "Can't get id of $dn from the table");
+            $self->log(level => 'err', message => "Can't get id of $dn from the table");
             $rc = LDAP_OPERATIONS_ERROR;
             last DO;
         }
@@ -726,7 +724,7 @@ sub _objAdd
 
                 $sth = $self->{db}->prepare("$sql");
                 if (!$sth->execute) {
-                    $self->log(level => 'error', message => "Adding storage-specific information by \"$sql\" failed: ".$sth->errstr);
+                    $self->log(level => 'err', message => "Adding storage-specific information by \"$sql\" failed: ".$sth->errstr);
                     $rc = LDAP_OPERATIONS_ERROR;
                     last DO;
                 }
@@ -738,7 +736,7 @@ sub _objAdd
         foreach my $attr (keys %attrs) {
             foreach my $value (@{$attrs{$attr}}) {
                 if ($rc = $self->_addAttrValues($oconf, $key, $pkey, $attr, $value, $dn, $entryStr)) {
-                    $self->log(level => 'error', message => "Adding values of $attr failed");
+                    $self->log(level => 'err', message => "Adding values of $attr failed");
                     $rc = LDAP_OPERATIONS_ERROR;
                     last DO;
                 }
@@ -753,7 +751,7 @@ sub _objAdd
             $sql = $self->_funcParse($sql, $dn, $entryStr);
             $sth = $self->{db}->prepare("$sql");
             if (!$sth->execute) {
-                $self->log(level => 'error', message => "Adding link of container by \"$sql\" failed: ".$sth->errstr);
+                $self->log(level => 'err', message => "Adding link of container by \"$sql\" failed: ".$sth->errstr);
                 $rc = LDAP_OPERATIONS_ERROR;
                 last DO;
             }
@@ -787,7 +785,7 @@ sub _objDelete
     DO: {
         # start transaction
         if (!$self->{db}->begin_work) {
-            $self->log(level => 'error', message => "Can't begin: ".$self->{db}->errstr);
+            $self->log(level => 'err', message => "Can't begin: ".$self->{db}->errstr);
             $rc = LDAP_OPERATIONS_ERROR;
             last DO;
         }
@@ -836,7 +834,7 @@ sub _objDelete
 
                 $sth = $self->{db}->prepare("$sql");
                 if (!$sth->execute) {
-                    $self->log(level => 'error', message => "Deleting storage-specific information by \"$sql\" failed: ".$sth->errstr);
+                    $self->log(level => 'err', message => "Deleting storage-specific information by \"$sql\" failed: ".$sth->errstr);
                     $rc = LDAP_OPERATIONS_ERROR;
                     last DO;
                 }
@@ -856,7 +854,7 @@ sub _objDelete
             $sql = $self->_funcParse($sql, $dn);
             $sth = $self->{db}->prepare("$sql");
             if (!$sth->execute) {
-                $self->log(level => 'error', message => "Adding link of container by \"$sql\" failed: ".$sth->errstr);
+                $self->log(level => 'err', message => "Adding link of container by \"$sql\" failed: ".$sth->errstr);
                 $rc = LDAP_OPERATIONS_ERROR;
                 last DO;
             }
@@ -867,7 +865,7 @@ sub _objDelete
         $sql = "delete from $oconf->{table}[0] where $oconf->{id}[0]->{column}[0] = \'$key\'";
         $sth = $self->{db}->prepare($sql);
         if (!$sth->execute) {
-            $self->log(level => 'error', message => "Deleting entry by \"$sql\" failed: ".$sth->errstr);
+            $self->log(level => 'err', message => "Deleting entry by \"$sql\" failed: ".$sth->errstr);
             $rc = LDAP_OPERATIONS_ERROR;
             last DO;
         }
@@ -919,7 +917,7 @@ sub _getParentRdn
     my $sql = "select $selexpr from $from where $where";
     my $sth = $self->{db}->prepare($sql);
     if (!$sth->execute) {
-        $self->log(level => 'error', message => "Getting rdn by \"$sql\" failed: ".$sth->errstr);
+        $self->log(level => 'err', message => "Getting rdn by \"$sql\" failed: ".$sth->errstr);
         return undef;
     }
 
@@ -1000,7 +998,7 @@ sub _getAttrValues
     my $sql = "select $selexpr from $from where $where";
     my $sth = $self->{db}->prepare($sql);
     if (!$sth->execute) {
-        $self->log(level => 'error', message => "Getting $attr values by \"$sql\" failed: ".$sth->errstr);
+        $self->log(level => 'err', message => "Getting $attr values by \"$sql\" failed: ".$sth->errstr);
         return undef;
     }
 
@@ -1056,10 +1054,10 @@ sub _addAttrValues
             my $attrkey;
             ($rc, $attrkey) =$self->_baseSearch($aobj, $attrpkey, $value, 0, 0, 1, 0, undef);
             if ($rc) {
-                $self->log(level => 'error', message => "Can't get id of $value in the table");
+                $self->log(level => 'err', message => "Can't get id of $value in the table");
                 return -1;
             } elsif (!$attrkey) {
-		$self->log(level => 'error', message => "Id of $value doesn't exist in the table");
+		$self->log(level => 'err', message => "Id of $value doesn't exist in the table");
                 return 1;
             }
             $sql =~ s/\%a/$attrkey/g;
@@ -1076,10 +1074,10 @@ sub _addAttrValues
                 my $contkey;
                 ($rc, $contkey) =$self->_baseSearch($cobj, $contpkey, $contdn, 0, 0, 1, 0, undef);
                 if ($rc) {
-                    $self->log(level => 'error', message => "Can't get id of $contdn in the table");
+                    $self->log(level => 'err', message => "Can't get id of $contdn in the table");
                     return -1;
                 } elsif (!$contkey) {
-                    $self->log(level => 'error', message => "Id of $contdn doesn't exist in the table");
+                    $self->log(level => 'err', message => "Id of $contdn doesn't exist in the table");
                     return 1;
                 }
                 $sql =~ s/\%c/$contkey/g;
@@ -1096,7 +1094,7 @@ sub _addAttrValues
         # add the values to the attribute's table
 	my $sth = $self->{db}->prepare($sql);
         if (!$sth->execute) {
-            $self->log(level => 'error', message => "Adding $attr values by \"$sql\" failed: ".$sth->errstr);
+            $self->log(level => 'err', message => "Adding $attr values by \"$sql\" failed: ".$sth->errstr);
             return -1;
         }
         $sth->finish;
@@ -1129,10 +1127,10 @@ sub _delAttrValues
                 my $attrkey;
                 ($rc, $attrkey) =$self->_baseSearch($aobj, $attrpkey, $value, 0, 0, 1, 0, undef);
                 if ($rc) {
-		    $self->log(level => 'error', message => "Can't get id of $value from the table");
+		    $self->log(level => 'err', message => "Can't get id of $value from the table");
                     return -1;
                 } elsif (!$attrkey) {
-		    $self->log(level => 'error', message => "Id of $value doesn't exist in the table");
+		    $self->log(level => 'err', message => "Id of $value doesn't exist in the table");
                     return 1;
                 }
                 $sql =~ s/\%a/$attrkey/g;
@@ -1149,10 +1147,10 @@ sub _delAttrValues
                     my $contkey;
                     ($rc, $contkey) =$self->_baseSearch($cobj, $contpkey, $contdn, 0, 0, 1, 0, undef);
                     if ($rc) {
-                        $self->log(level => 'error', message => "Can't get id of $contdn in the table");
+                        $self->log(level => 'err', message => "Can't get id of $contdn in the table");
                         return -1;
                     } elsif (!$contkey) {
-                        $self->log(level => 'error', message => "Id of $contdn doesn't exist in the table");
+                        $self->log(level => 'err', message => "Id of $contdn doesn't exist in the table");
                         return 1;
                     }
                     $sql =~ s/\%c/$contkey/g;
@@ -1173,7 +1171,7 @@ sub _delAttrValues
         # delete the values from the attribute's table
         my $sth = $self->{db}->prepare($sql);
         if (!$sth->execute) {
-            $self->log(level => 'error', message => "Deleting $attr values by \"$sql\" failed: ".$sth->errstr);
+            $self->log(level => 'err', message => "Deleting $attr values by \"$sql\" failed: ".$sth->errstr);
             return -1;
         }
         $sth->finish;
